@@ -1,15 +1,15 @@
 import re
-import sys
 import subprocess
+import sys
 from functools import cached_property
-from typing import Union, List, Optional
+from typing import List, Union
 
 from yaml import load
 
 try:
-    from yaml import CLoader as Loader, CDumper as Dumper
+    from yaml import CLoader as Loader
 except ImportError:
-    from yaml import Loader, Dumper
+    from yaml import Loader
 
 
 ######################################
@@ -44,8 +44,8 @@ class Utils:
         return result
 
 
-class NestorDescSet():
-    def __init__(self, init: List["NestorDesc"]=None):
+class NestorDescSet:
+    def __init__(self, init: List["NestorDesc"] = None):
         self.values = set()
         self.add(init or [])
 
@@ -77,7 +77,6 @@ class NestorDescSet():
                     self.values.remove(v)
                 self.values.add(v)
 
-
     def __getitem__(self, item):
         to_find = item
         if isinstance(to_find, str):
@@ -198,8 +197,6 @@ class NestorOpt(NestorDesc):
         )
 
 
-
-
 class NestorGitDesc(NestorDesc):
     """Python class to handle the yml part of the Odoo operator
     branch: ""
@@ -244,7 +241,6 @@ class NestorGitDesc(NestorDesc):
 
 
 class NestorPersistenceDesc(NestorDesc):
-
     def __init__(self, s3_secret: str = None, s3_bucket: str = None, enable_s3: bool = True):
         self.s3_secret = s3_secret
         self.s3_bucket = s3_bucket
@@ -252,14 +248,14 @@ class NestorPersistenceDesc(NestorDesc):
 
     def to_set_opt(self) -> NestorDescSet:
         values = NestorDescSet()
-        values.add(NestorOpt('persistence.disabled', self.enable_s3))
+        values.add(NestorOpt("persistence.disabled", self.enable_s3))
         if self.s3_secret:
-            values.add(NestorOpt('persistence.s3.secret', self.s3_secret))
+            values.add(NestorOpt("persistence.s3.secret", self.s3_secret))
         if self.s3_bucket:
-            values.add(NestorOpt('persistence.s3.bucket', self.s3_bucket))
+            values.add(NestorOpt("persistence.s3.bucket", self.s3_bucket))
         if self.s3_secret and self.s3_bucket:
-            values.add(NestorOpt('persistence.s3.allowWrite', True))
-            values.add(NestorOpt('persistence.s3.enabled', self.enable_s3))
+            values.add(NestorOpt("persistence.s3.allowWrite", True))
+            values.add(NestorOpt("persistence.s3.enabled", self.enable_s3))
         return values
 
 
@@ -295,9 +291,9 @@ class NestorInstance:
 
     def version(self, values: NestorDescSet = None):
         if self.exist():
-            value = self.spec['version']
+            value = self.spec["version"]
         elif values:
-            value = values['version'] and values['version'].value
+            value = values["version"] and values["version"].value
         else:
             raise ValueError("Version can't be found")
         return int(float(value))
@@ -333,11 +329,15 @@ class NestorInstance:
         workers = workers or 2
         memory_soft = memory_soft or 450_000_000  # 450Mo
         memory_hard = memory_hard or 1_000_000_000  # 1000Mo
-        self.edit(NestorDescSet([
-            NestorOpt("options.limitMemoryHard", memory_hard),
-            NestorOpt("options.limitMemorySoft", memory_soft),
-            NestorOpt("workers", workers),
-        ]))
+        self.edit(
+            NestorDescSet(
+                [
+                    NestorOpt("options.limitMemoryHard", memory_hard),
+                    NestorOpt("options.limitMemorySoft", memory_soft),
+                    NestorOpt("workers", workers),
+                ]
+            )
+        )
 
     @staticmethod
     def list():
@@ -365,12 +365,12 @@ class NestorInstance:
         self._call(["filestore", "dump"], "s3", ".", "--progress", "--bucket", bucket or self.name, "--s3", s3_secret)
 
     def db_restore_from_s3(
-            self,
-            dump_path: str,
-            s3_secret: str = None,
-            bucket: str = None,
-            set_password_to_all: bool = False,
-            verbose: bool = False,
+        self,
+        dump_path: str,
+        s3_secret: str = None,
+        bucket: str = None,
+        set_password_to_all: bool = False,
+        verbose: bool = False,
     ) -> int:
 
         return NestorDatabaseCmd(self).restore("s3", dump_path, s3_secret, bucket, set_password_to_all, verbose)
@@ -440,7 +440,7 @@ class NestorInstance:
 
     @cached_property
     def spec(self) -> dict:
-        return load(self.show("yaml"), Loader)['spec']
+        return load(self.show("yaml"), Loader)["spec"]
 
     @cached_property
     def spec_text(self):
@@ -466,13 +466,13 @@ class NestorDatabaseCmd:
         self._inst = inst
 
     def restore(
-            self,
-            type: str,
-            dump_path: str,
-            s3_secret: str = None,
-            bucket: str = None,
-            set_password_to_all: bool = False,
-            verbose: bool = False,
+        self,
+        type: str,
+        dump_path: str,
+        s3_secret: str = None,
+        bucket: str = None,
+        set_password_to_all: bool = False,
+        verbose: bool = False,
     ) -> int:
         opt = [type, dump_path]
         if s3_secret:
@@ -498,25 +498,23 @@ class NestorDatabaseCmd:
 
 
 class NestorFileStoreCommand:
-
     def __init__(self, instance: NestorInstance):
         self.inst = instance
 
-    def enable_on_s3_spec(self, s3_secret: str, s3_bucket: str = None, values:NestorDescSet=None):
+    def enable_on_s3_spec(self, s3_secret: str, s3_bucket: str = None, values: NestorDescSet = None):
         assert s3_secret, "A s3 secret is required"
         assert self.inst.version(values) <= 14, "V15 not supported yet"
 
         s3_bucket = s3_bucket or self.inst.name
         specs = NestorPersistenceDesc(s3_secret, s3_bucket, enable_s3=True).to_set_opt()
-        loads = (values['options.load'] or NestorOpt("options.load", "")).value.split(",")
-
+        loads = (values["options.load"] or NestorOpt("options.load", "")).value.split(",")
 
         if self.inst.version(values) == 14:
-            path = 'odoo/cloud-modules'  # New repo only for 14.0 for now
+            path = "odoo/cloud-modules"  # New repo only for 14.0 for now
             if "odoo_filestore_s3" not in loads:
                 loads.append("odoo_filestore_s3")
         else:
-            path = 'kubernetes/odoo-modules'
+            path = "kubernetes/odoo-modules"
             if "odoo_s3" not in loads:
                 loads.append("odoo_s3")
         for idx in [""] + list(range(2, 20)):
@@ -533,12 +531,21 @@ class NestorFileStoreCommand:
         assert s3_secret, "A s3 secret is required"
         s3_bucket = s3_bucket or self.inst.name
 
-        self.inst._call(["filestore", "dump"], "s3", ".", "--progress", "--bucket", s3_bucket or self.inst.name, "--s3",
-                        s3_secret)
+        self.inst._call(
+            ["filestore", "dump"], "s3", ".", "--progress", "--bucket", s3_bucket or self.inst.name, "--s3", s3_secret
+        )
 
     def restore_from_s3(self, s3_secret, s3_bucket):
-        self.inst._call(["filestore", "restore"], "s3", ".", "--progress", "--bucket", s3_bucket or self.inst.name,
-                        "--s3", s3_secret)
+        self.inst._call(
+            ["filestore", "restore"],
+            "s3",
+            ".",
+            "--progress",
+            "--bucket",
+            s3_bucket or self.inst.name,
+            "--s3",
+            s3_secret,
+        )
 
 
 class ScriptNestorInstance(NestorInstance):
